@@ -1,3 +1,24 @@
+/*
+ * callforwarding - Call forwarding control panel applet for N900
+ * Copyright (C) 2009  Mikko Mehtonen <mikko.mehtonen@vincit.fi>
+ * 
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ * 
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
+ * 
+ * You should have received a copy of the GNU General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307  USA
+ * 
+ */
+
+
 #include <hildon/hildon.h>
 #include <gtk/gtk.h>
 #include <string.h>
@@ -34,7 +55,6 @@ void callforwardingdialog_show (GtkWindow *parent,
                                 const gchar *title,
                                 gint type)
 {
-  printf("callforwardingdialog_show\n");
   call_forwarding_type = type;
   dialog = gtk_dialog_new_with_buttons (
                               title,
@@ -86,27 +106,31 @@ void callforwardingdialog_show (GtkWindow *parent,
                                        HILDON_BUTTON_ARRANGEMENT_VERTICAL);
     hildon_picker_button_set_selector (HILDON_PICKER_BUTTON(picker), HILDON_TOUCH_SELECTOR(selector));
     hildon_button_set_title (HILDON_BUTTON (picker), _("Seconds before fowarding"));
+    hildon_button_set_alignment (HILDON_BUTTON (picker), 0, 0, 0, 0);
     gtk_box_pack_start (GTK_BOX(vbox), picker, FALSE, FALSE, 0);
   }
 
   gtk_container_add (GTK_CONTAINER(GTK_DIALOG(dialog)->vbox), vbox);
-  gtk_widget_show_all (dialog);
 
+  /* Set dialog insensitive while settings are loaded */
   hildon_gtk_window_set_progress_indicator (GTK_WINDOW(dialog), TRUE);
   gtk_widget_set_sensitive (button, FALSE);
   gtk_widget_set_sensitive (entry, FALSE);
   gtk_widget_set_sensitive (label, FALSE);
   gtk_widget_set_sensitive (select_contact, FALSE);
+  gtk_dialog_set_response_sensitive (GTK_DIALOG(dialog), GTK_RESPONSE_OK, FALSE);
   if (picker != NULL)
   {
     gtk_widget_set_sensitive (picker, FALSE);
   }
+  gtk_widget_show_all (dialog);
 
   callforwarding_get_status (type, callforwarding_status_reply);
 }
 
 static void set_dialog_sensitivity (void)
 {
+  gtk_dialog_set_response_sensitive (GTK_DIALOG(dialog), GTK_RESPONSE_OK, TRUE);
   gtk_widget_set_sensitive (button, TRUE);
   gboolean sensitive = hildon_check_button_get_active (HILDON_CHECK_BUTTON(button));
 
@@ -133,12 +157,10 @@ static void dialog_response (GtkDialog *dialog,
                              gint response,
                              gpointer user_data)
 {
-  printf("dialog_response\n");
   const gchar *number = NULL;
   switch (response)
   {
     case GTK_RESPONSE_OK:
-      printf("GTK_RESPONSE_OK\n");
       if (hildon_check_button_get_active (HILDON_CHECK_BUTTON(button)))
       {
         /* save */
@@ -148,9 +170,18 @@ static void dialog_response (GtkDialog *dialog,
             hildon_banner_show_information (GTK_WIDGET(dialog), NULL, _("Enter number"));
             return;
         }
+        gtk_dialog_set_response_sensitive (GTK_DIALOG(dialog), GTK_RESPONSE_OK, FALSE);
         hildon_gtk_window_set_progress_indicator (GTK_WINDOW(dialog), TRUE);
-        gtk_widget_set_sensitive (GTK_WIDGET(dialog), FALSE);
         gint time = 20;
+        if (picker != NULL)
+        {
+          gint index = hildon_picker_button_get_active (picker);
+          if (index >= 0 && index < 6)
+          {
+            int times[] = {5, 10, 15, 20, 25, 30};
+            time = times[index];
+          }
+        }
         callforwarding_activate (call_forwarding_type, number, time, callforwarding_activate_reply);
       } else {
         /* cancel */
@@ -161,7 +192,6 @@ static void dialog_response (GtkDialog *dialog,
       break;
 
     default:
-      printf("default\n");
       callforwarding_cancel_pending_call ();
       gtk_widget_destroy (GTK_WIDGET(dialog));
   }
@@ -170,13 +200,11 @@ static void dialog_response (GtkDialog *dialog,
 
 static void callforwarding_status_reply (GError *error, gboolean status, gchar *number)
 {
-
   if (error != NULL)
   {
-    printf("Error while reading call forwarding state: %s\n", error->message);
+    hildon_banner_show_information (dialog, NULL, _("Error while reading status"));
     g_clear_error (&error);
   } else {
-    printf("state=%i, number=%s\n", status, number);
     hildon_check_button_set_active (HILDON_CHECK_BUTTON(button), status);
     if (number != NULL)
     {
@@ -193,6 +221,7 @@ static void callforwarding_cancel_reply (GError *error)
 {
   if (error != NULL)
   {
+    hildon_banner_show_information (dialog, NULL, _("Error while canceling call forwarding"));
     printf("Error while canceling call forwarding: %s\n", error->message);
     g_clear_error (&error);
   }
@@ -204,7 +233,6 @@ static void callforwarding_activate_reply (GError *error)
 {
   if (error != NULL)
   {
-    gtk_widget_set_sensitive (dialog, TRUE);
     set_dialog_sensitivity ();
     hildon_gtk_window_set_progress_indicator (GTK_WINDOW(dialog), FALSE);
     hildon_banner_show_information (dialog, NULL, _("Not allowed"));
